@@ -1,7 +1,7 @@
 
 from herre.wards.query import TypedQuery
 from herre.access.object import GraphQLObject
-from herre.config.model import BaseConfig
+from herre.config.herre import BaseConfig
 from herre.auth import HerreClient, get_current_herre
 from herre.wards.graphql import ParsedQuery, GraphQLWard
 
@@ -12,6 +12,10 @@ class FlussConfig(BaseConfig):
     port: int
     secure: bool
 
+    class Config:
+        yaml_group = "fluss"
+        env_prefix = "fluss_"
+
 
 
 class FlussWard(GraphQLWard):
